<meta name="google-site-verification" content="rnnwgvWL65WRkF2NxC8H0l-YSArRZGXA1qfp9e8Ox_8" />

# XIMG-EMBL project

This package is the part of the project on Research and Development of phase-contrast X-ray tomography at the P14 EMBL beamline at PETRA-III (DESY). It can do:

- [Flatfield-correction for unstable illumination conditions (monochromator vibrations)](https://github.com/maximka48/XIMG-EMBL/blob/master/examples_public/demo_SSIM_1d-PR.ipynb)
- [Parallel-based image filtering with multiprocessing](https://github.com/maximka48/XIMG-EMBL/blob/master/examples_public/demo_SSIM_1d-PR.ipynb)
- [Single-distance Phase retrieval (Paganin, Bronnikov, CTF algorithms)](https://github.com/maximka48/XIMG-EMBL/blob/master/examples_public/demo_SSIM_1d-PR.ipynb)
- Phase retrieval with multi-distance CTF-based approach
- Parallel-beam X-ray tomography

- [Various simple functions for image processing](https://github.com/maximka48/XIMG-EMBL/blob/master/maximus48/var.py)
- [Transformation of the image from Courtesian to Polar coordinates](https://github.com/maximka48/XIMG-EMBL/blob/master/examples_public/Courtesian-2-Polar.ipynb)



I try to update the examples timely so the user could get an idea of usage. However, you may also find useful to check each function or class have a situational description.
Feel free to contact me should you have any questions.

Maxim Polikarpov
polikarpov.maxim@mail.ru

https://maximka48.github.io/XIMG-EMBL/

